﻿using System;
using UIKit;
using Infragistics;
using CoreGraphics;
using Foundation;
using ObjCRuntime;
using System.Collections.Generic;

namespace TooltipOnLineChartCS
{
	public partial class ViewController : UIViewController, IIGChartViewDelegate
	{
		IGCategorySeriesDataSourceHelper _source;
		List<NSObject> _data;

		protected ViewController(IntPtr handle) : base(handle)
		{
			// Note: this .ctor should not contain any initialization logic.
		}

		public override void ViewDidLoad()
		{
			base.ViewDidLoad();


			CGRect chartRect = this.View.Bounds;
			chartRect.Inflate (-15, -15);

			IGChartView chartView = new IGChartView(chartRect);
			chartView.AutoresizingMask = UIViewAutoresizing.FlexibleWidth | UIViewAutoresizing.FlexibleHeight;
			chartView.ZoomDisplayType = IGChartZoom.IGChartZoomHorizontal;
			chartView.CrosshairsBackground = new UIColor(0.27f, 0.67f, 0.84f, 1.0f);
			chartView.CrosshairsThickness = 3;
			chartView.CrosshairsVisibility = IGCrosshairsVisibility.IGCrosshairsVisibilityVertical;
			chartView.TooltipPinLocation = IGTooltipPinLocation.IGTooltipPinLocationTop;
			chartView.Theme = IGChartGradientThemes.IGTheme();
			chartView.WeakDelegate = this;
			this.View.Add (chartView);

			_data = new List<NSObject> ();
			Random r = new Random();
			for(int i = 0; i< 25; i++)
			{
				double val = r.Next() % 100;
				_data.Add(new NSNumber(val));
			}
			_source = new IGCategorySeriesDataSourceHelper(_data.ToArray());
			IGLineSeries lineSeries = chartView.AddSeries(new Class("IGLineSeries"), "lineSeries", _source, "xAxis", "yAxis") as IGLineSeries;
			lineSeries.YAxis.Maximum = 100;
		}

		[Export("chartView:viewForTooltipWithItemlist:")]
		public UIKit.UIView ResolveTooltipView(global::Infragistics.IGChartView chartView, Foundation.NSDictionary itemlist)
		{
			UIView tooltip = new UIView(new CGRect(0, 0, 100, 30));
			tooltip.Layer.CornerRadius = 4;
			tooltip.BackgroundColor = UIColor.LightGray;
			if (itemlist.Count > 0)
			{
				string seriesKey = itemlist.Keys.GetValue(0).ToString();
				double pointValue = ((IGCategoryPoint)itemlist.ValueForKey(new NSString(seriesKey))).Value;
				UILabel valueLabel = new UILabel();
				valueLabel.BackgroundColor = UIColor.Clear;
				valueLabel.Text = String.Format("${0:0.00}", pointValue);
				valueLabel.SizeToFit();
				valueLabel.Frame = new CGRect(5, 5, (float)valueLabel.Frame.Size.Width, (float)valueLabel.Frame.Size.Height);
				valueLabel.Center = new CGPoint(tooltip.Bounds.Width / 2, tooltip.Bounds.Height / 2);
				tooltip.AddSubview(valueLabel);
			}

			return tooltip;
		}

		public override void DidReceiveMemoryWarning()
		{
			base.DidReceiveMemoryWarning();
			// Release any cached data, images, etc that aren't in use.
		}
	}
}
